from arlas.cli.collections import collections
from arlas.cli.index import indices
import typer
import os
import sys
from typing_extensions import Annotated
from typing import Optional

from arlas.cli.variables import variables, configuration_file
from arlas.cli.settings import ARLAS, Configuration, Resource, Settings

app = typer.Typer()
arlas_cli_version = "0.0.14"


def version_callback():
    print(arlas_cli_version)
    raise typer.Exit()


@app.callback()
def collections_callback(
    arlas_configuration: str = typer.Argument(help="Name of the ARLAS configuration to use from your configuration file ({})".format(configuration_file)),
    version: Annotated[Optional[bool], typer.Option("--version", callback=version_callback)] = None
):
    variables["arlas"] = arlas_configuration
    if os.path.exists(configuration_file):
        Configuration.init(configuration_file=configuration_file)
        if Configuration.settings.arlas and len(Configuration.settings.arlas) > 0:
            # Configuration is ok.
            ...
        else:
            print("Error : no arlas endpoint found in {}.".format(configuration_file), file=sys.stderr)
            sys.exit(1)
    else:
        # we create a template to facilitate the creation of the configuration file
        print(os.path.dirname(configuration_file))
        os.makedirs(os.path.dirname(configuration_file), exist_ok=True)
        Configuration.settings = Settings(
            arlas={
                "demo": ARLAS(server=Resource(location="https://demo.cloud.arlas.io/arlas/server", headers={"Content-Type": "application/json"})),
                "local": ARLAS(
                    server=Resource(location="http://localhost:9999/arlas", headers={"Content-Type": "application/json"}),
                    elastic=Resource(location="http://localhost:9200/", headers={"Content-Type": "application/json"}),
                    allow_delete=True
                )
            },
            mappings={
                "arlas_eo": Resource(location="https://raw.githubusercontent.com/gisaia/ARLAS-EO/master/mapping.json")
            },
            models={
                "arlas_eo": Resource(location="https://raw.githubusercontent.com/gisaia/ARLAS-EO/master/collection.json")
            }
        )
        Configuration.save(configuration_file)
        print("Error : no configuration file found, we created an empty one for you ({}).".format(configuration_file), file=sys.stderr)
        sys.exit(1)


def main():
    app.add_typer(collections, name="collections")
    app.add_typer(indices, name="indices")
    app()


if __name__ == "__main__":
    main()
